#!/usr/bin/python
import os
from time import time
import argparse
from treecutter.directory import Directory
from treecutter.sitemap import Sitemap

def main():

    parser = argparse.ArgumentParser(description='Process docbook article tree.')
    parser.add_argument('--style', nargs='?',
                        default=os.path.dirname(os.getcwd())+'/style/default/')
    parser.add_argument('--output', nargs='?',
                        default=os.path.dirname(os.getcwd())+'/htdocs/')
    args = parser.parse_args()

    ts = time()
    dir_ = Directory()
    sitemap = Sitemap()

    # Scanning current directory and subdirectory for docbook articles
    dir_.scan()
    # Reading the sitemap.txt building a Trie structure
    sitemap.read_map()

    # Comparing the current state of the dir with the sitemap
    missing = dir_.set() - sitemap.set()
    removed = sitemap.set() - dir_.set()
    for page in removed:
        print page+' pages missing!!'
    for page in missing:
        print 'adding missing page '+page
        sitemap.add_link(page)
    if len(missing)+len(removed) != 0:
        print 'writing new sitemap - please adjust if needed'
        sitemap.write_map()

    # Generate a pygraphviz image of the site (TODO: currently not used)
    sitemap.graph()
    # Start processing the docbook articles to static html
    sitemap.process(args.style)

    # Publish static html and style data (css, images, fonts) to destination dir
    t1 = time()
    sitemap.publish(args.output,args.style)
    t2 = time()
    print "Publish  [%5.2f s]" % (round(t2-t1,2))
    print "Total    [%5.2f s]" % (round(t2-ts,2))
    return 0

if __name__ == "__main__":
    sys.exit(main())
